#!/bin/sh

set -e

# This is an install/update script for DebianParl
# DebianParl Homepage: https://wiki.debian.org/DebianParl
# Source of this code: git://git.debian.org/parl/blends

# Workaround for dictionaries-common install failure (bug#751367)
aptitude install apt-utils

# Administration
#  * include package usage reporting Popularity-Contest
#  * include APT hook apt-listchanges
#  * include bash-completion and uuid-runtime recommended by essential packages
#  * mark misc. packages, relevant only as dependencies, as auto-installed
#  * enable unattended package upgrades
# Console media
#  * include core ALSA audio tools
#  * include PulseAudio console tools
# Desktop
#  * include GNOME system tools
#  * include GNOME-oriented NetworkManager client
#  * include screensaver unicode-screensaver
#  * include desktop editor Mousepad
#  * include desktop hardening helper tools
# Desktop email
#  * include Icedove email client
#  * include Icedove sieve plugin
#  * include Icedove PGP plugin
#  * include Icedove locale for Danish
#  * include Icedove locale for German
#  * include Icedove locale for British English
#  * include Icedove locale for Finnish
#  * include Icedove locales for European Union (except Maltese)
# desktop-environment-xfce
#  * include the lightweight Xfce desktop
#  * include Xfce power management tools
#  * include Xfce file manager
#  * include Xfce notification manager
#  * exclude Xfce audio handling
# Filesystem desktop handling
#  * include Xfce locate frontend linelight
# Desktop media
#  * include simple ALSA volume control Volti
#  * include PulseAudio desktop volume control
#  * include video player Mpv
#  * exclude PulseAudio wrapper for legacy audio system EsounD
#  * exclude video player MPlayer2
# Desktop mobile
#  * include desktop tools to syncronize with mobile devices
# Desktop office
#  * include document viewer Evince
#  * include LibreOffice theme tango
#  * include LibreOffice integration with GTK+ 2.x
#  * include LibreOffice Writer
#  * include LibreOffice Calc
#  * include LibreOffice Impress
#  * exclude LibreOffice Database
#  * include LibreOffice Danish locale
#  * include LibreOffice German locale
#  * include LibreOffice British English locale
#  * include LibreOffice locales for European Union (except Maltese)
# Desktop photo
#  * include photo manager Shotwell
# Desktop scheduling
#  * include Icedove extension Iceowl
#  * include Iceowl locale for Danish
#  * include Iceowl locale for German
#  * include Iceowl locale for British English
#  * include Iceowl locales for European Union
# Desktop web
#  * include Iceweasel web browser
#  * include Iceweasel security plugins
#  * include Iceweasel Danish locale
#  * include Iceweasel German locale
#  * include Iceweasel locales for European Union (except Maltese)
# Framework
#  * include Tango icon theme
#  * include Xfce themes for GTK+ 2.0
#  * exclude WebKit GTK+ 1.0 library (used for maybe-risky PAC proxy parsing)
# Crypto framework
#  * include GTK+ PIN entry interface for GnuPG
# Media framework
#  * exclude MIDI patches
# Package framework
#  * include command-line and Curses APT frontend aptitude
# Hardware
#  * include support for Bluetooth hardware
#  * include OpenGL hardware rasterizers
#  * exclude OpenGL software rasterizers
#  * include low-level crypto hardening tools
# Service
#  * include sleep-supporting command scheduler service anacron
#  * include Network Time Protocol service OpenNTPD
# Audio service
#  * include PulseAudio audio daemon
# Filesystem service
#  * include locate-compatible data indexer mlocate
# Print service
#  * avoid support for Gutenprint based printers
#  * avoid support for HP GDI printers
#  * avoid support for HP IJS printers
#  * avoid support for HP JetReady 4.x printers
#  * avoid support for HP LIP printers
#  * avoid minimal support for (some) HP printers
#  * avoid support for (mostly Minolta) ZjStream based printers
#  * avoid support for Konica Minolta PagePro printers
#  * avoid support for Ricoh Aficio GDI printers
#  * avoid support for Samsung SPL2/SPLc printers
#  * Avoid CUPS printing system
#  * avoid CUPS support for printing via Bluetooth
aptitude install task-laptop acpi-support acpi-support-base alsa-utils anacron apt-listchanges aptitude bash-completion bluez enigmail evince gnome-disk-utility gnome-system-tools gtk2-engines-xfce gvfs haveged hunspell-de-at hunspell-de-ch hunspell-de-de hunspell-en-gb hunspell-lt hunspell-ro hyphen-da hyphen-de hyphen-en-gb ibritish ibulgarian icedove icedove-l10n-bg icedove-l10n-cs icedove-l10n-da icedove-l10n-de icedove-l10n-el icedove-l10n-en-gb icedove-l10n-es-es icedove-l10n-et icedove-l10n-fi icedove-l10n-fr icedove-l10n-ga-ie icedove-l10n-hr icedove-l10n-hu icedove-l10n-it icedove-l10n-nl icedove-l10n-pl icedove-l10n-pt-pt icedove-l10n-ro icedove-l10n-sk icedove-l10n-sl icedove-l10n-sv-se iceowl-extension iceowl-l10n-bg iceowl-l10n-cs iceowl-l10n-da iceowl-l10n-de iceowl-l10n-el iceowl-l10n-en-gb iceowl-l10n-es-es iceowl-l10n-et iceowl-l10n-fi iceowl-l10n-fr iceowl-l10n-ga-ie iceowl-l10n-hr iceowl-l10n-hr iceowl-l10n-hu iceowl-l10n-it iceowl-l10n-lt iceowl-l10n-nl iceowl-l10n-pl iceowl-l10n-pt-pt iceowl-l10n-ro iceowl-l10n-sk iceowl-l10n-sl iceowl-l10n-sv-se iceweasel iceweasel-l10n-bg iceweasel-l10n-cs iceweasel-l10n-el iceweasel-l10n-en-gb iceweasel-l10n-es-es iceweasel-l10n-et iceweasel-l10n-fi iceweasel-l10n-fr iceweasel-l10n-ga-ie iceweasel-l10n-hr iceweasel-l10n-hu iceweasel-l10n-it iceweasel-l10n-nl iceweasel-l10n-pl iceweasel-l10n-pt-pt iceweasel-l10n-ro iceweasel-l10n-sk iceweasel-l10n-sl iceweasel-l10n-sv-se iczech idanish idutch iestonian ifrench ihungarian iirish iitalian ilithuanian ingerman iogerman ipolish iportuguese ispanish iswedish libgl1-mesa-dri libreoffice-calc libreoffice-gtk libreoffice-impress libreoffice-l10n-bg libreoffice-l10n-cs libreoffice-l10n-da libreoffice-l10n-de libreoffice-l10n-el libreoffice-l10n-en-gb libreoffice-l10n-es libreoffice-l10n-et libreoffice-l10n-fi libreoffice-l10n-fr libreoffice-l10n-hr libreoffice-l10n-hu libreoffice-l10n-it libreoffice-l10n-lt libreoffice-l10n-lv libreoffice-l10n-nl libreoffice-l10n-pl libreoffice-l10n-pt libreoffice-l10n-ro libreoffice-l10n-sk libreoffice-l10n-sl libreoffice-l10n-sv libreoffice-ogltrans libreoffice-style-tango libreoffice-writer lightdm manpages-de mlocate mousepad mpv myspell-bg myspell-cs myspell-da myspell-el-gr myspell-es myspell-et myspell-fr myspell-ga myspell-hr myspell-hu myspell-it myspell-lv myspell-nl myspell-pl myspell-pt-pt myspell-sk myspell-sl myspell-sv-se network-manager-gnome nuntius openntpd parcimonie pasystray pavucontrol pinentry-gtk2 popularity-contest pulseaudio pulseaudio-utils shotwell sync-ui tango-icon-theme thunar tmispell-voikko unattended-upgrades unicode-screensaver uuid-runtime volti wbritish wbulgarian wdanish wdutch wfrench witalian wngerman wogerman wpolish wportuguese wspanish wswedish xfce4-linelight-plugin xfce4-notifyd xfce4-power-manager xfce4-power-manager-plugins xfce4-session xserver-xorg xul-ext-certificatepatrol xul-ext-cookie-monster xul-ext-flashblock xul-ext-mozvoikko xul-ext-noscript xul-ext-refcontrol xul-ext-requestpolicy xul-ext-sieve xul-ext-y-u-no-validate \
 bluez-cups- cpufrequtils- cups- evince-gtk- freepats- hplip- hunspell-da- hunspell-de-at-frami- hunspell-de-ch-frami- hunspell-de-de-frami- libgl1-mesa-swx11- libreoffice-base- libreoffice-emailmerge- libreoffice-java-common- libwebkitgtk-1.0-0- mplayer2- myspell-de-at- myspell-de-ch- myspell-de-de- myspell-de-de-oldspell- printer-driver-foo2zjs- printer-driver-gutenprint- printer-driver-hpcups- printer-driver-hpijs- printer-driver-min12xxw- printer-driver-pnm2ppa- printer-driver-postscript-hp- printer-driver-pxljr- printer-driver-sag-gdi- printer-driver-splix- pulseaudio-esound-compat- xfce4-mixer- xfce4-volumed- xfce4-volumed-

# Administration
#  * define routines to make backup of and help edit config files
#  * define routines to resolve package dependencies
#  * fix mark auto-installed essential packages + dependencies
#  * auto-repair inconsistent filesystems during boot
# desktop-environment-xfce
#  * silence confusing panel question at initial login
#  * replace appfinder with mail-reader in default panel
#  * disable storing session at logout by default
# Hardware
#  * sleep when lid is closed
apt-mark auto \
  acpi-support-base aptitude-common bash-completion evolution-data-server grub-common gvfs isc-dhcp-common lightdm-gtk-greeter pulseaudio-utils tasksel-data uuid-runtime vim-common xserver-xorg
 _backup(){ set -e;\
  if [ -e "$1" ]; then \
    if [ -e "$1.orig" ]; then \
      cp -a "$1" "$1.bak";\
    else \
      cp -a "$1" "$1.orig";\
    fi;\
  else \
    touch "$1.orig";\
  fi; };\
 _backup_todir(){ set -e;\
  dir="${2:-$(dirname "$1").bak}";\
  [ -e "$dir" ] || mkdir -p "$dir";\
  path="$dir/$(basename "$1")";\
  if [ -e "$1" ]; then \
    cp -fa "$1" "$path";\
  else \
    touch "$path";\
  fi; };\
 _clone(){ set -e;\
  test -e "$1";\
  _backup "$2";\
  cp -fa "$1" "$2"; };\
 _setline(){ set -e;\
  _backup "$1";\
  if [ $# = 3 ]; then \
    sed -i -r \
      -e "s!^#?($2)\$!$3!g" "$1";\
  else \
    sed -i -r \
      -e "s!^#?($2)\$!\\1!g" "$1";\
  fi; };\
 _setappendline(){ set -e;\
  if [ -e "$1" ] && egrep -q "^#?$2\$" "$1"; then \
    _setline "$@";\
  else \
    _backup "$1";\
    echo "${3:-$2}" >> "$1";\
  fi; };\
 _setvar(){ set -e;\
  _backup "$1";\
  sed -i -r \
    -e "s!^#?($2)=.*!\\1=$3!" "$1"; };\
 _setappendvar(){ set -e;\
  if [ -e "$1" ] && egrep -q "^#?$2=" "$1"; then \
    _setvar "$@";\
  else \
    _backup "$1";\
    echo "$2=$3" >> "$1";\
  fi; };\
 _setvar /etc/default/acpi-support LID_SLEEP true;\
 _pkgdeps(){ set -e;\
  dpkg-query \
    -Wf=',${Pre-Depends},${Depends},${Recommends}\n' $* 2>/dev/null \
    | sed -r \
    -e 's/[,|] *([a-z0-9.+-]+)?(:\s+)?( *[^|,]*)?/\1\n/g' \
    | sed '/^$/d'|sort -u; };\
 _pkg2re(){ set -e;\
  echo $* \
    | sed -r \
    -e 's/\s+/\|/g;' \
    -e 's/^\|//;' \
    -e 's/([.+-])/\\\1/g;' \
    -e 's/\|$//'; };\
 _pkgreal(){ set -e;\
  dpkg-query \
    -Wf='${Package},${Provides},\n' \
    | sed -r \
    -e '/,,/d;' \
    -e 's/^([a-z0-9.+-]+).*[,|] *('"$(_pkg2re $*)"')[ :,]/\1/;' \
    -e '/,/d'; };\
 _pkganddeepdeps(){ set -e;\
  rest=$*;\
  all=$rest;\
  for i in 1 2 3 4 5; do \
    deps=$(_pkgdeps $rest);\
    rest="$deps $(_pkgreal $deps)";\
    all="$all $rest";\
  done;\
  echo $all \
    | sed -r \
    -e 's/\s+/\n/g' \
    | sort -u; };\
 _pkgessentials(){ set -e;\
  dpkg-query \
    -Wf='${Package}%${Essential}\n' \
    | sed -r \
    -e 's/(.*)%yes/\1/;' \
    -e '/%/d'; };\
 apt-mark auto \
  $(_pkganddeepdeps $(_pkgessentials) apt) || true;\
 _setvar /etc/default/rcS FSCKFIX yes;\
 cd /etc/xdg/xfce4/xfconf/xfce-perchannel-xml;\
 _clone ../../panel/default.xml xfce4-panel.xml;\
 sed -i -r \
  -e 's,xfce4-appfinder,exo-mail-reader,' \
  xfce4-panel.xml;\
 _backup xfce4-session.xml;\
 sed -i -r \
  -e 's,(<property name="general"[^>]*>),\1\n    <property name="SaveOnExit" type="bool" value="false"/>,' \
  xfce4-session.xml
