#!/bin/sh

set -e

# This is an install/update script for DebianParl
# DebianParl Homepage: https://wiki.debian.org/DebianParl
# Source of this code: git://git.debian.org/parl/blends

# Workaround for dictionaries-common install failure (bug#751367)
aptitude install apt-utils

# Administration
#  * include package usage reporting Popularity-Contest
#  * include APT hook apt-listchanges
#  * include bash-completion and uuid-runtime recommended by essential packages
#  * mark misc. packages, relevant only as dependencies, as auto-installed
#  * enable unattended package upgrades
# Console media
#  * include core ALSA audio tools
#  * include PulseAudio console tools
# Desktop
#  * include GNOME system tools
#  * include GNOME-oriented NetworkManager client
#  * include screensaver unicode-screensaver
#  * include desktop editor Mousepad
#  * include desktop hardening helper tools
# Desktop email
#  * include Icedove email client
#  * include Icedove sieve plugin
#  * include Icedove PGP plugin
#  * include Icedove locale for British English
#  * include Icedove locale for South African English
#  * include Icedove locales for Africa
#  * include Icedove locale for American English
#  * include Icedove locale for American English
#  * include Icedove locales for Americas
#  * include Icedove locale for Bengali (Bangladesh)
#  * include Icedove locale for Bengali (India)
#  * include Icedove locale for Gujarati
#  * include Icedove locale for Hindi
#  * include Icedove locale for Malayalam
#  * include Icedove locale for Nepali
#  * include Icedove locale for Punjabi (India)
#  * include Icedove locale for Tamil (Sri Lanka)
#  * include Icedove locale for Tamil
#  * include Icedove locale for Telugu
#  * include Icedove support for bidirectional text
#  * include Icedove locales for official languages of India
#  * include Icedove locale for Punjabi
#  * include Icedove locales for Asia (UN M.49 definition)
#  * include Icedove locale for Danish
#  * include Icedove locale for German
#  * include Icedove locale for Finnish
#  * include Icedove locales for European Union (except Maltese)
#  * include Icedove locales for Europe (UN M.49 definition)
#  * include all Icedove locales
# desktop-environment-xfce
#  * include the lightweight Xfce desktop
#  * include Xfce power management tools
#  * include Xfce file manager
#  * include Xfce notification manager
#  * exclude Xfce audio handling
# Filesystem desktop handling
#  * include Xfce locate frontend linelight
# Desktop media
#  * include simple ALSA volume control Volti
#  * include PulseAudio desktop volume control
#  * include video player Mpv
#  * exclude PulseAudio wrapper for legacy audio system EsounD
#  * exclude video player MPlayer2
# Desktop mobile
#  * include desktop tools to syncronize with mobile devices
# Desktop office
#  * include document viewer Evince
#  * include LibreOffice theme tango
#  * include LibreOffice integration with GTK+ 2.x
#  * include LibreOffice Writer
#  * include LibreOffice Calc
#  * include LibreOffice Impress
#  * exclude LibreOffice Database
#  * include LibreOffice Afrikaans locale
#  * include LibreOffice South African English locale
#  * include LibreOffice Transvaal Ndebele locale
#  * include LibreOffice Northern Sotho locale
#  * include LibreOffice Swazi locale
#  * include LibreOffice Southern Soto locale
#  * include LibreOffice Tswana locale
#  * include LibreOffice Tsonga locale
#  * include LibreOffice Venda locale
#  * include LibreOffice Xhosa locale
#  * include LibreOffice Zulu locale
#  * include LibreOffice locales for official languages of South Africa
#  * include LibreOffice locales for Africa
#  * include LibreOffice locales for Americas
#  * include LibreOffice Assamese locale
#  * include LibreOffice Bengali locale
#  * include LibreOffice British English locale
#  * include LibreOffice Gujarati locale
#  * include LibreOffice Hindi locale
#  * include LibreOffice Kannada locale
#  * include LibreOffice Malayalam locale
#  * include LibreOffice Marathi locale
#  * include LibreOffice Nepali locale
#  * include LibreOffice Odia (a.k.a. Oriya or Orya) locale
#  * include LibreOffice Punjabi locale
#  * include LibreOffice Tamil locale
#  * include LibreOffice Telugu locale
#  * include LibreOffice locales for official languages of India
#  * include LibreOffice locales for Asia
#  * include LibreOffice Danish locale
#  * include LibreOffice German locale
#  * include LibreOffice locales for European Union (except Maltese)
#  * include LibreOffice locales for Europe (UN M.49 definition)
#  * include all LibreOffice locales
# Desktop photo
#  * include photo manager Shotwell
# Desktop scheduling
#  * include Icedove extension Iceowl
#  * include Iceowl locale for British English
#  * include Iceowl locale for South African English
#  * include Iceowl locales for official languages of South Africa
#  * include Iceowl locales for Africa
#  * include Iceowl locales for Americas
#  * include iceowl locale for Bengali (Bangladesh)
#  * include iceowl locale for Bengali
#  * include iceowl locale for Punjabi (India)
#  * include iceowl locale for Tamil (Sri Lanka)
#  * include iceowl locale for Tamil
#  * include Iceowl locales for official languages of India
#  * include iceowl locale for Punjabi
#  * include Iceowl locales for Asia (UN M.49 definition)
#  * include Iceowl locale for Danish
#  * include Iceowl locale for German
#  * include Iceowl locales for European Union
#  * include Iceowl locales for Europe (UN M.49 definition)
#  * include all Iceowl locales
# Desktop web
#  * include Iceweasel web browser
#  * include Iceweasel security plugins
#  * include Iceweasel Afrikaans locale
#  * include Iceweasel locale for South African English
#  * include Iceweasel Xhosa locale
#  * include Iceweasel locales for official languages of South Africa
#  * include Iceweasel locales for Africa
#  * include Iceweasel locale for American English
#  * include Iceweasel locale for American English
#  * include Iceweasel locales for Americas
#  * include Iceweasel Assamese locale
#  * include Iceweasel locale for Bengali (India)
#  * include Iceweasel locale for British English
#  * include Iceweasel Gujarati locale
#  * include Iceweasel Hindi locale
#  * include Iceweasel Kannada locale
#  * include Iceweasel Malayalam locale
#  * include Iceweasel Marathi locale
#  * include Iceweasel locale for Nepali
#  * include Iceweasel Odia (a.k.a. Oriya or Orya) locale
#  * include Iceweasel locale for Punjabi (India)
#  * include Iceweasel Tamil locale
#  * include Iceweasel Telugu locale
#  * include Iceweasel locales for official languages of India
#  * include Iceweasel locale for Bengali (Bangladesh)
#  * include Iceweasel locale for Punjabi
#  * include Iceweasel locales for Asia
#  * include Iceweasel Danish locale
#  * include Iceweasel German locale
#  * include Iceweasel locales for European Union (except Maltese)
#  * include Iceweasel locales for Europe (UN M.49 definition)
#  * include all Iceweasel locales
# Framework
#  * include Tango icon theme
#  * include Xfce themes for GTK+ 2.0
#  * exclude WebKit GTK+ 1.0 library (used for maybe-risky PAC proxy parsing)
# Crypto framework
#  * include GTK+ PIN entry interface for GnuPG
# Media framework
#  * exclude MIDI patches
# Package framework
#  * include command-line and Curses APT frontend aptitude
# Hardware
#  * include support for Bluetooth hardware
#  * include OpenGL hardware rasterizers
#  * exclude OpenGL software rasterizers
#  * include low-level crypto hardening tools
# Service
#  * include sleep-supporting command scheduler service anacron
#  * include Network Time Protocol service OpenNTPD
# Audio service
#  * include PulseAudio audio daemon
# Filesystem service
#  * include locate-compatible data indexer mlocate
# Print service
#  * avoid support for Gutenprint based printers
#  * avoid support for HP GDI printers
#  * avoid support for HP IJS printers
#  * avoid support for HP JetReady 4.x printers
#  * avoid support for HP LIP printers
#  * avoid minimal support for (some) HP printers
#  * avoid support for (mostly Minolta) ZjStream based printers
#  * avoid support for Konica Minolta PagePro printers
#  * avoid support for Ricoh Aficio GDI printers
#  * avoid support for Samsung SPL2/SPLc printers
#  * Avoid CUPS printing system
#  * avoid CUPS support for printing via Bluetooth
aptitude install task-laptop acpi-support acpi-support-base alsa-utils anacron apt-listchanges aptitude aspell-en aspell-eo bash-completion bluez enigmail evince gnome-disk-utility gnome-system-tools gtk2-engines-xfce gvfs haveged hunspell-af hunspell-an hunspell-ar hunspell-be hunspell-bn hunspell-br hunspell-bs hunspell-de-at hunspell-de-ch hunspell-de-de hunspell-en-au hunspell-en-ca hunspell-en-gb hunspell-en-us hunspell-en-za hunspell-eu hunspell-gd hunspell-gl-es hunspell-gu hunspell-hi hunspell-is hunspell-kk hunspell-kmr hunspell-ko hunspell-lo hunspell-lt hunspell-ml hunspell-ne hunspell-no hunspell-no hunspell-oc hunspell-ro hunspell-se hunspell-si hunspell-sr hunspell-sw hunspell-te hunspell-th hunspell-uk hunspell-uz hunspell-vi hyphen-af hyphen-as hyphen-bn hyphen-da hyphen-de hyphen-en-gb hyphen-en-us hyphen-kn hyphen-mr hyphen-pa hyphen-ta hyphen-zu iamerican ibritish ibulgarian icatalan icedove icedove-bidiui icedove-l10n-ar icedove-l10n-ast icedove-l10n-be icedove-l10n-bg icedove-l10n-bn-bd icedove-l10n-br icedove-l10n-ca icedove-l10n-cs icedove-l10n-da icedove-l10n-de icedove-l10n-el icedove-l10n-en-gb icedove-l10n-es-ar icedove-l10n-es-es icedove-l10n-et icedove-l10n-eu icedove-l10n-fi icedove-l10n-fr icedove-l10n-fy-nl icedove-l10n-ga-ie icedove-l10n-gl icedove-l10n-he icedove-l10n-hr icedove-l10n-hu icedove-l10n-hy-am icedove-l10n-id icedove-l10n-is icedove-l10n-it icedove-l10n-ja icedove-l10n-ko icedove-l10n-nl icedove-l10n-pa-in icedove-l10n-pl icedove-l10n-pt-br icedove-l10n-pt-pt icedove-l10n-rm icedove-l10n-ro icedove-l10n-ru icedove-l10n-ru icedove-l10n-si icedove-l10n-sk icedove-l10n-sl icedove-l10n-sq icedove-l10n-sr icedove-l10n-sv-se icedove-l10n-ta-lk icedove-l10n-tr icedove-l10n-tr icedove-l10n-uk icedove-l10n-vi icedove-l10n-zh-cn icedove-l10n-zh-tw iceowl-extension iceowl-l10n-ar iceowl-l10n-be iceowl-l10n-bg iceowl-l10n-bn-bd iceowl-l10n-br iceowl-l10n-ca iceowl-l10n-cs iceowl-l10n-cy iceowl-l10n-da iceowl-l10n-de iceowl-l10n-el iceowl-l10n-en-gb iceowl-l10n-es-ar iceowl-l10n-es-es iceowl-l10n-et iceowl-l10n-eu iceowl-l10n-fi iceowl-l10n-fr iceowl-l10n-fy-nl iceowl-l10n-ga-ie iceowl-l10n-gd iceowl-l10n-gl iceowl-l10n-he iceowl-l10n-hr iceowl-l10n-hr iceowl-l10n-hu iceowl-l10n-hy-am iceowl-l10n-id iceowl-l10n-is iceowl-l10n-it iceowl-l10n-ja iceowl-l10n-ko iceowl-l10n-lt iceowl-l10n-nb-no iceowl-l10n-nl iceowl-l10n-nn-no iceowl-l10n-pa-in iceowl-l10n-pl iceowl-l10n-pt-br iceowl-l10n-pt-pt iceowl-l10n-rm iceowl-l10n-ro iceowl-l10n-ru iceowl-l10n-ru iceowl-l10n-si iceowl-l10n-sk iceowl-l10n-sl iceowl-l10n-sq iceowl-l10n-sr iceowl-l10n-sv-se iceowl-l10n-ta-lk iceowl-l10n-tr iceowl-l10n-tr iceowl-l10n-uk iceowl-l10n-vi iceowl-l10n-zh-cn iceowl-l10n-zh-tw iceweasel iceweasel-l10n-ach iceweasel-l10n-af iceweasel-l10n-an iceweasel-l10n-ar iceweasel-l10n-as iceweasel-l10n-ast iceweasel-l10n-az iceweasel-l10n-be iceweasel-l10n-bg iceweasel-l10n-bn-bd iceweasel-l10n-bn-in iceweasel-l10n-br iceweasel-l10n-bs iceweasel-l10n-ca iceweasel-l10n-cs iceweasel-l10n-cy iceweasel-l10n-dsb iceweasel-l10n-el iceweasel-l10n-en-gb iceweasel-l10n-en-gb iceweasel-l10n-en-za iceweasel-l10n-eo iceweasel-l10n-es-ar iceweasel-l10n-es-cl iceweasel-l10n-es-es iceweasel-l10n-es-mx iceweasel-l10n-et iceweasel-l10n-eu iceweasel-l10n-fa iceweasel-l10n-ff iceweasel-l10n-fi iceweasel-l10n-fr iceweasel-l10n-fy-nl iceweasel-l10n-ga-ie iceweasel-l10n-gd iceweasel-l10n-gl iceweasel-l10n-gn iceweasel-l10n-gu-in iceweasel-l10n-he iceweasel-l10n-hi-in iceweasel-l10n-hr iceweasel-l10n-hsb iceweasel-l10n-hu iceweasel-l10n-hy-am iceweasel-l10n-id iceweasel-l10n-is iceweasel-l10n-it iceweasel-l10n-ja iceweasel-l10n-kk iceweasel-l10n-kk iceweasel-l10n-km iceweasel-l10n-kn iceweasel-l10n-kn iceweasel-l10n-ko iceweasel-l10n-lij iceweasel-l10n-lv iceweasel-l10n-mai iceweasel-l10n-mk iceweasel-l10n-ml iceweasel-l10n-mr iceweasel-l10n-ms iceweasel-l10n-nl iceweasel-l10n-or iceweasel-l10n-pa-in iceweasel-l10n-pl iceweasel-l10n-pt-br iceweasel-l10n-pt-pt iceweasel-l10n-rm iceweasel-l10n-ro iceweasel-l10n-ru iceweasel-l10n-ru iceweasel-l10n-si iceweasel-l10n-sk iceweasel-l10n-sl iceweasel-l10n-son iceweasel-l10n-sq iceweasel-l10n-sr iceweasel-l10n-sv-se iceweasel-l10n-ta iceweasel-l10n-te iceweasel-l10n-th iceweasel-l10n-tr iceweasel-l10n-tr iceweasel-l10n-uz iceweasel-l10n-vi iceweasel-l10n-xh iceweasel-l10n-zh-cn iceweasel-l10n-zh-tw iczech idanish idutch iesperanto iestonian ifaroese ifrench igaelic igalician-minimos ihungarian iirish iitalian ilithuanian imanx ingerman iogerman ipolish iportuguese irussian ispanish iswedish iswiss itagalog iukrainian libgl1-mesa-dri libreoffice-calc libreoffice-gtk libreoffice-impress libreoffice-l10n-af libreoffice-l10n-am libreoffice-l10n-ar libreoffice-l10n-as libreoffice-l10n-ast libreoffice-l10n-be libreoffice-l10n-bg libreoffice-l10n-bn libreoffice-l10n-br libreoffice-l10n-bs libreoffice-l10n-ca libreoffice-l10n-cs libreoffice-l10n-cy libreoffice-l10n-da libreoffice-l10n-de libreoffice-l10n-dz libreoffice-l10n-el libreoffice-l10n-en-gb libreoffice-l10n-en-za libreoffice-l10n-eo libreoffice-l10n-es libreoffice-l10n-et libreoffice-l10n-eu libreoffice-l10n-fa libreoffice-l10n-fi libreoffice-l10n-fr libreoffice-l10n-ga libreoffice-l10n-gl libreoffice-l10n-gu libreoffice-l10n-gug libreoffice-l10n-he libreoffice-l10n-hi libreoffice-l10n-hr libreoffice-l10n-hu libreoffice-l10n-id libreoffice-l10n-in libreoffice-l10n-is libreoffice-l10n-it libreoffice-l10n-ja libreoffice-l10n-ka libreoffice-l10n-kk libreoffice-l10n-km libreoffice-l10n-kmr libreoffice-l10n-ko libreoffice-l10n-lt libreoffice-l10n-lv libreoffice-l10n-mk libreoffice-l10n-ml libreoffice-l10n-mn libreoffice-l10n-mr libreoffice-l10n-nb libreoffice-l10n-ne libreoffice-l10n-ne libreoffice-l10n-nl libreoffice-l10n-nn libreoffice-l10n-nr libreoffice-l10n-nso libreoffice-l10n-oc libreoffice-l10n-om libreoffice-l10n-or libreoffice-l10n-pa-in libreoffice-l10n-pl libreoffice-l10n-pt libreoffice-l10n-pt-br libreoffice-l10n-ro libreoffice-l10n-ru libreoffice-l10n-ru libreoffice-l10n-rw libreoffice-l10n-si libreoffice-l10n-sk libreoffice-l10n-sl libreoffice-l10n-sr libreoffice-l10n-ss libreoffice-l10n-st libreoffice-l10n-sv libreoffice-l10n-ta libreoffice-l10n-te libreoffice-l10n-tg libreoffice-l10n-th libreoffice-l10n-tn libreoffice-l10n-tr libreoffice-l10n-tr libreoffice-l10n-ts libreoffice-l10n-ug libreoffice-l10n-uk libreoffice-l10n-uz libreoffice-l10n-ve libreoffice-l10n-vi libreoffice-l10n-xh libreoffice-l10n-zh-cn libreoffice-l10n-zh-tw libreoffice-l10n-zu libreoffice-ogltrans libreoffice-style-tango libreoffice-writer lightdm mlocate mousepad mpv myspell-bg myspell-ca myspell-cs myspell-da myspell-el-gr myspell-eo myspell-es myspell-et myspell-fa myspell-fr myspell-ga myspell-gv myspell-he myspell-hr myspell-hu myspell-hy myspell-it myspell-lv myspell-nl myspell-pl myspell-pt-br myspell-pt-pt myspell-ru myspell-sk myspell-sl myspell-sv-se myspell-tl mythes-en-au mythes-en-us mythes-es mythes-fr mythes-pt-pt network-manager-gnome nuntius openntpd parcimonie pasystray pavucontrol pinentry-gtk2 popularity-contest pulseaudio pulseaudio-utils shotwell sync-ui tango-icon-theme thunar tmispell-voikko unattended-upgrades unicode-screensaver uuid-runtime volti wamerican wbritish wbulgarian wcanadian wcatalan wdanish wdutch wfaroese wfrench wgalician-minimos witalian wngerman wogerman wpolish wportuguese wspanish wswedish wswiss wukrainian xfce4-linelight-plugin xfce4-notifyd xfce4-power-manager xfce4-power-manager-plugins xfce4-session xserver-xorg xul-ext-certificatepatrol xul-ext-cookie-monster xul-ext-flashblock xul-ext-mozvoikko xul-ext-noscript xul-ext-refcontrol xul-ext-requestpolicy xul-ext-sieve xul-ext-y-u-no-validate \
 bluez-cups- cpufrequtils- cups- evince-gtk- freepats- hplip- hunspell-da- hunspell-de-at-frami- hunspell-de-ch-frami- hunspell-de-de-frami- libgl1-mesa-swx11- libreoffice-base- libreoffice-emailmerge- libreoffice-java-common- libwebkitgtk-1.0-0- mplayer2- myspell-de-at- myspell-de-ch- myspell-de-de- myspell-de-de-oldspell- printer-driver-foo2zjs- printer-driver-gutenprint- printer-driver-hpcups- printer-driver-hpijs- printer-driver-min12xxw- printer-driver-pnm2ppa- printer-driver-postscript-hp- printer-driver-pxljr- printer-driver-sag-gdi- printer-driver-splix- pulseaudio-esound-compat- xfce4-mixer- xfce4-volumed- xfce4-volumed-

# Administration
#  * define routines to make backup of and help edit config files
#  * define routines to resolve package dependencies
#  * fix mark auto-installed essential packages + dependencies
#  * auto-repair inconsistent filesystems during boot
# desktop-environment-xfce
#  * silence confusing panel question at initial login
#  * replace appfinder with mail-reader in default panel
#  * disable storing session at logout by default
# Hardware
#  * sleep when lid is closed
apt-mark auto \
  acpi-support-base aptitude-common bash-completion evolution-data-server grub-common gvfs isc-dhcp-common libreoffice-l10n-af libreoffice-l10n-en-za libreoffice-l10n-nr libreoffice-l10n-nso libreoffice-l10n-ss libreoffice-l10n-st libreoffice-l10n-tn libreoffice-l10n-ts libreoffice-l10n-ve libreoffice-l10n-xh libreoffice-l10n-zu lightdm-gtk-greeter pulseaudio-utils tasksel-data uuid-runtime vim-common xserver-xorg
 _backup(){ set -e;\
  if [ -e "$1" ]; then \
    if [ -e "$1.orig" ]; then \
      cp -a "$1" "$1.bak";\
    else \
      cp -a "$1" "$1.orig";\
    fi;\
  else \
    touch "$1.orig";\
  fi; };\
 _backup_todir(){ set -e;\
  dir="${2:-$(dirname "$1").bak}";\
  [ -e "$dir" ] || mkdir -p "$dir";\
  path="$dir/$(basename "$1")";\
  if [ -e "$1" ]; then \
    cp -fa "$1" "$path";\
  else \
    touch "$path";\
  fi; };\
 _clone(){ set -e;\
  test -e "$1";\
  _backup "$2";\
  cp -fa "$1" "$2"; };\
 _setline(){ set -e;\
  _backup "$1";\
  if [ $# = 3 ]; then \
    sed -i -r \
      -e "s!^#?($2)\$!$3!g" "$1";\
  else \
    sed -i -r \
      -e "s!^#?($2)\$!\\1!g" "$1";\
  fi; };\
 _setappendline(){ set -e;\
  if [ -e "$1" ] && egrep -q "^#?$2\$" "$1"; then \
    _setline "$@";\
  else \
    _backup "$1";\
    echo "${3:-$2}" >> "$1";\
  fi; };\
 _setvar(){ set -e;\
  _backup "$1";\
  sed -i -r \
    -e "s!^#?($2)=.*!\\1=$3!" "$1"; };\
 _setappendvar(){ set -e;\
  if [ -e "$1" ] && egrep -q "^#?$2=" "$1"; then \
    _setvar "$@";\
  else \
    _backup "$1";\
    echo "$2=$3" >> "$1";\
  fi; };\
 _setvar /etc/default/acpi-support LID_SLEEP true;\
 _pkgdeps(){ set -e;\
  dpkg-query \
    -Wf=',${Pre-Depends},${Depends},${Recommends}\n' $* 2>/dev/null \
    | sed -r \
    -e 's/[,|] *([a-z0-9.+-]+)?(:\s+)?( *[^|,]*)?/\1\n/g' \
    | sed '/^$/d'|sort -u; };\
 _pkg2re(){ set -e;\
  echo $* \
    | sed -r \
    -e 's/\s+/\|/g;' \
    -e 's/^\|//;' \
    -e 's/([.+-])/\\\1/g;' \
    -e 's/\|$//'; };\
 _pkgreal(){ set -e;\
  dpkg-query \
    -Wf='${Package},${Provides},\n' \
    | sed -r \
    -e '/,,/d;' \
    -e 's/^([a-z0-9.+-]+).*[,|] *('"$(_pkg2re $*)"')[ :,]/\1/;' \
    -e '/,/d'; };\
 _pkganddeepdeps(){ set -e;\
  rest=$*;\
  all=$rest;\
  for i in 1 2 3 4 5; do \
    deps=$(_pkgdeps $rest);\
    rest="$deps $(_pkgreal $deps)";\
    all="$all $rest";\
  done;\
  echo $all \
    | sed -r \
    -e 's/\s+/\n/g' \
    | sort -u; };\
 _pkgessentials(){ set -e;\
  dpkg-query \
    -Wf='${Package}%${Essential}\n' \
    | sed -r \
    -e 's/(.*)%yes/\1/;' \
    -e '/%/d'; };\
 apt-mark auto \
  $(_pkganddeepdeps $(_pkgessentials) apt) || true;\
 _setvar /etc/default/rcS FSCKFIX yes;\
 cd /etc/xdg/xfce4/xfconf/xfce-perchannel-xml;\
 _clone ../../panel/default.xml xfce4-panel.xml;\
 sed -i -r \
  -e 's,xfce4-appfinder,exo-mail-reader,' \
  xfce4-panel.xml;\
 _backup xfce4-session.xml;\
 sed -i -r \
  -e 's,(<property name="general"[^>]*>),\1\n    <property name="SaveOnExit" type="bool" value="false"/>,' \
  xfce4-session.xml
